Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1127)

Unified Diff: chrome/test/data/webui/md_history/md_history_browsertest.js

Issue 2771443002: Revert of WebUI: Disable all JS tests in MSAN, ASAN, and TSAN bots. (Closed)
Patch Set: Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/test/BUILD.gn ('k') | chrome/test/data/webui/sandboxstatus_browsertest.js » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/test/data/webui/md_history/md_history_browsertest.js
diff --git a/chrome/test/data/webui/md_history/md_history_browsertest.js b/chrome/test/data/webui/md_history/md_history_browsertest.js
index ebcb6ab538f42eb06ade22334e88702e77393b67..22d988a1b02ee6bd0f34470dc23e08812aea1eee 100644
--- a/chrome/test/data/webui/md_history/md_history_browsertest.js
+++ b/chrome/test/data/webui/md_history/md_history_browsertest.js
@@ -107,9 +107,10 @@
]),
};
-// Times out on debug builders because the History page can take several seconds
-// to load in a Debug build. See https://crbug.com/669227.
-GEN('#if !defined(NDEBUG)');
+// Times out on debug builders and may time out on memory bots because
+// the History page can take several seconds to load in a Debug build. See
+// https://crbug.com/669227.
+GEN('#if defined(MEMORY_SANITIZER) || !defined(NDEBUG)');
GEN('#define MAYBE_All DISABLED_All');
GEN('#else');
GEN('#define MAYBE_All All');
« no previous file with comments | « chrome/test/BUILD.gn ('k') | chrome/test/data/webui/sandboxstatus_browsertest.js » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698